From a67c11ffbfc9e922753491c2f51a75d019c544bb Mon Sep 17 00:00:00 2001
From: "J. Nick Koston" <nick@cpanel.net>
Date: Thu, 1 Dec 2016 01:38:02 -0600
Subject: [PATCH] config: Match multiple names in local_name

This can significantly reduce memory usage when using
a UCC certificate with multiple names by only loading
the certificate and key once.
---
 src/config/config-filter.c | 17 ++++++++++++++++-
 1 file changed, 16 insertions(+), 1 deletion(-)

diff --git a/src/config/config-filter.c b/src/config/config-filter.c
index 426a326..139eebf 100644
--- a/src/config/config-filter.c
+++ b/src/config/config-filter.c
@@ -37,8 +37,23 @@ static bool config_filter_match_rest(const struct config_filter *mask,
 	if (mask->local_name != NULL) {
 		if (filter->local_name == NULL)
 			return FALSE;
-		if (dns_match_wildcard(filter->local_name, mask->local_name) != 0)
+		/* Handle multiple names seperated by spaces in local_name
+		 * Ex: local_name "mail.domain.tld domain.tld mx.domain.tld" { ... } */
+		if (strstr(mask->local_name, " ") != NULL) {
+			const char *const *local_name = t_strsplit_spaces(mask->local_name, " ");
+			int matched = 0;
+			for (; *local_name != NULL; local_name++) {
+				if (dns_match_wildcard(filter->local_name, *local_name) == 0) {
+					matched = 1;
+					break;
+				}
+			}
+			if (!matched)
+				return FALSE;
+		/* Handle a single local_name */
+		} else if (dns_match_wildcard(filter->local_name, mask->local_name) != 0) {
 			return FALSE;
+		}
 	}
 	/* FIXME: it's not comparing full masks */
 	if (mask->remote_bits != 0) {
-- 
2.10.2

